@@ -31,8 +31,8 @@ import importlib.resources as pkg_resources
 
 #DATA_DIR = os.path.join(os.path.dirname(__file__), 'data')
 
-EXTRACTOR_FILENAME = pkg_resources.resource_stream('taloncb', 'signature/data/classifier')
-EXTRACTOR_DATA = pkg_resources.resource_stream('taloncb', 'signature/data/train.data')
+EXTRACTOR_FILENAME = pkg_resources.open_text('taloncb', 'signature/data/classifier')
+EXTRACTOR_DATA = pkg_resources.open_text('taloncb', 'signature/data/train.data')
 
 
 def initialize():
